package com.hw.mes.service;

import java.util.List;
import com.hw.mes.domain.MesBindBarcode;

/**
 * 条码绑定信息Service接口
 * 
 * @author xins
 * @date 2023-12-28
 */
public interface IMesBindBarcodeService 
{
    /**
     * 查询条码绑定信息
     * 
     * @param bindBarcodeId 条码绑定信息主键
     * @return 条码绑定信息
     */
    public MesBindBarcode selectMesBindBarcodeByBindBarcodeId(Long bindBarcodeId);

    /**
     * 查询条码绑定信息列表
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 条码绑定信息集合
     */
    public List<MesBindBarcode> selectMesBindBarcodeList(MesBindBarcode mesBindBarcode);

    /**
     * 新增条码绑定信息
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 结果
     */
    public int insertMesBindBarcode(MesBindBarcode mesBindBarcode);

    /**
     * 修改条码绑定信息
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 结果
     */
    public int updateMesBindBarcode(MesBindBarcode mesBindBarcode);

    /**
     * 批量删除条码绑定信息
     * 
     * @param bindBarcodeIds 需要删除的条码绑定信息主键集合
     * @return 结果
     */
    public int deleteMesBindBarcodeByBindBarcodeIds(Long[] bindBarcodeIds);

    /**
     * 删除条码绑定信息信息
     * 
     * @param bindBarcodeId 条码绑定信息主键
     * @return 结果
     */
    public int deleteMesBindBarcodeByBindBarcodeId(Long bindBarcodeId);
}
