package com.hw.mes.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.hw.common.security.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.mes.domain.MesBindBarcode;
import com.hw.mes.service.IMesBindBarcodeService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 条码绑定信息Controller
 * 
 * @author xins
 * @date 2023-12-28
 */
@RestController
@RequestMapping("/bindbarcode")
public class MesBindBarcodeController extends BaseController
{
    @Autowired
    private IMesBindBarcodeService mesBindBarcodeService;

    /**
     * 查询条码绑定信息列表
     */
    @RequiresPermissions("mes:bindbarcode:list")
    @GetMapping("/list")
    public TableDataInfo list(MesBindBarcode mesBindBarcode)
    {
        startPage();
        List<MesBindBarcode> list = mesBindBarcodeService.selectMesBindBarcodeList(mesBindBarcode);
        return getDataTable(list);
    }

    /**
     * 导出条码绑定信息列表
     */
    @RequiresPermissions("mes:bindbarcode:export")
    @Log(title = "条码绑定信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MesBindBarcode mesBindBarcode)
    {
        List<MesBindBarcode> list = mesBindBarcodeService.selectMesBindBarcodeList(mesBindBarcode);
        ExcelUtil<MesBindBarcode> util = new ExcelUtil<MesBindBarcode>(MesBindBarcode.class);
        util.exportExcel(response, list, "条码绑定信息数据");
    }

    /**
     * 获取条码绑定信息详细信息
     */
    @RequiresPermissions("mes:bindbarcode:query")
    @GetMapping(value = "/{bindBarcodeId}")
    public AjaxResult getInfo(@PathVariable("bindBarcodeId") Long bindBarcodeId)
    {
        return success(mesBindBarcodeService.selectMesBindBarcodeByBindBarcodeId(bindBarcodeId));
    }

    /**
     * 新增条码绑定信息
     */
    @RequiresPermissions("mes:bindbarcode:add")
    @Log(title = "条码绑定信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MesBindBarcode mesBindBarcode)
    {
        mesBindBarcode.setCreateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBindBarcodeService.insertMesBindBarcode(mesBindBarcode));
    }

    /**
     * 修改条码绑定信息
     */
    @RequiresPermissions("mes:bindbarcode:edit")
    @Log(title = "条码绑定信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MesBindBarcode mesBindBarcode)
    {
        mesBindBarcode.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
        return toAjax(mesBindBarcodeService.updateMesBindBarcode(mesBindBarcode));
    }

    /**
     * 删除条码绑定信息
     */
    @RequiresPermissions("mes:bindbarcode:remove")
    @Log(title = "条码绑定信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{bindBarcodeIds}")
    public AjaxResult remove(@PathVariable Long[] bindBarcodeIds)
    {
        return toAjax(mesBindBarcodeService.deleteMesBindBarcodeByBindBarcodeIds(bindBarcodeIds));
    }
}
